Class: Google::Apis::GkehubV2::ConfigManagementDeploymentOverride
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::ConfigManagementDeploymentOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Configuration for a deployment override.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::GkehubV2::ConfigManagementContainerOverride>
Optional.
-
#deployment_name ⇒ String
Required.
-
#deployment_namespace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
constructor
A new instance of ConfigManagementDeploymentOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
Returns a new instance of ConfigManagementDeploymentOverride.
686 687 688 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::GkehubV2::ConfigManagementContainerOverride>
Optional. The containers of the deployment resource to be overridden.
Corresponds to the JSON property containers
674 675 676 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 674 def containers @containers end |
#deployment_name ⇒ String
Required. The name of the deployment resource to be overridden.
Corresponds to the JSON property deploymentName
679 680 681 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 679 def deployment_name @deployment_name end |
#deployment_namespace ⇒ String
Required. The namespace of the deployment resource to be overridden.
Corresponds to the JSON property deploymentNamespace
684 685 686 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 684 def deployment_namespace @deployment_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
691 692 693 694 695 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 691 def update!(**args) @containers = args[:containers] if args.key?(:containers) @deployment_name = args[:deployment_name] if args.key?(:deployment_name) @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace) end |