Class: Google::Apis::GkehubV2::ConfigManagementErrorResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Model for a config file in the git repo with an associated Sync error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementErrorResource

Returns a new instance of ConfigManagementErrorResource.



722
723
724
# File 'lib/google/apis/gkehub_v2/classes.rb', line 722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_gvkGoogle::Apis::GkehubV2::ConfigManagementGroupVersionKind

A Kubernetes object's GVK. Corresponds to the JSON property resourceGvk



705
706
707
# File 'lib/google/apis/gkehub_v2/classes.rb', line 705

def resource_gvk
  @resource_gvk
end

#resource_nameString

Metadata name of the resource that is causing an error Corresponds to the JSON property resourceName

Returns:

  • (String)


710
711
712
# File 'lib/google/apis/gkehub_v2/classes.rb', line 710

def resource_name
  @resource_name
end

#resource_namespaceString

Namespace of the resource that is causing an error Corresponds to the JSON property resourceNamespace

Returns:

  • (String)


715
716
717
# File 'lib/google/apis/gkehub_v2/classes.rb', line 715

def resource_namespace
  @resource_namespace
end

#source_pathString

Path in the git repo of the erroneous config Corresponds to the JSON property sourcePath

Returns:

  • (String)


720
721
722
# File 'lib/google/apis/gkehub_v2/classes.rb', line 720

def source_path
  @source_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



727
728
729
730
731
732
# File 'lib/google/apis/gkehub_v2/classes.rb', line 727

def update!(**args)
  @resource_gvk = args[:resource_gvk] if args.key?(:resource_gvk)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_namespace = args[:resource_namespace] if args.key?(:resource_namespace)
  @source_path = args[:source_path] if args.key?(:source_path)
end