Class: Google::Apis::GkehubV2::ConfigManagementPolicyControllerState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::ConfigManagementPolicyControllerState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
State for PolicyControllerState.
Instance Attribute Summary collapse
-
#deployment_state ⇒ Google::Apis::GkehubV2::ConfigManagementGatekeeperDeploymentState
State of Policy Controller installation.
-
#migration ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyControllerMigration
State for the migration of PolicyController from ACM -> PoCo Hub.
-
#version ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyControllerVersion
The build version of Gatekeeper Policy Controller is using.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementPolicyControllerState
constructor
A new instance of ConfigManagementPolicyControllerState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementPolicyControllerState
Returns a new instance of ConfigManagementPolicyControllerState.
1215 1216 1217 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_state ⇒ Google::Apis::GkehubV2::ConfigManagementGatekeeperDeploymentState
State of Policy Controller installation.
Corresponds to the JSON property deploymentState
1203 1204 1205 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1203 def deployment_state @deployment_state end |
#migration ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyControllerMigration
State for the migration of PolicyController from ACM -> PoCo Hub.
Corresponds to the JSON property migration
1208 1209 1210 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1208 def migration @migration end |
#version ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyControllerVersion
The build version of Gatekeeper Policy Controller is using.
Corresponds to the JSON property version
1213 1214 1215 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1213 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1220 1221 1222 1223 1224 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1220 def update!(**args) @deployment_state = args[:deployment_state] if args.key?(:deployment_state) @migration = args[:migration] if args.key?(:migration) @version = args[:version] if args.key?(:version) end |