Class: Google::Apis::GkehubV2::ConfigManagementSyncError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

An ACM created error representing a problem syncing configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncError

Returns a new instance of ConfigManagementSyncError.



1398
1399
1400
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

An ACM defined error code Corresponds to the JSON property code

Returns:

  • (String)


1386
1387
1388
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1386

def code
  @code
end

#error_messageString

A description of the error Corresponds to the JSON property errorMessage

Returns:

  • (String)


1391
1392
1393
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1391

def error_message
  @error_message
end

#error_resourcesArray<Google::Apis::GkehubV2::ConfigManagementErrorResource>

A list of config(s) associated with the error, if any Corresponds to the JSON property errorResources



1396
1397
1398
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1396

def error_resources
  @error_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1403
1404
1405
1406
1407
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1403

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @error_resources = args[:error_resources] if args.key?(:error_resources)
end