Class: Google::Apis::GkehubV2::FeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::FeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
FeatureState contains high-level state information and per-feature state information for this MembershipFeature.
Instance Attribute Summary collapse
-
#appdevexperience ⇒ Google::Apis::GkehubV2::AppDevExperienceState
State for App Dev Exp Feature.
-
#clusterupgrade ⇒ Google::Apis::GkehubV2::ClusterUpgradeState
Per-membership state for this feature.
-
#configmanagement ⇒ Google::Apis::GkehubV2::ConfigManagementState
Anthos Config Management: State for a single cluster.
-
#identityservice ⇒ Google::Apis::GkehubV2::IdentityServiceState
IdentityService: State for a single membership, analyzed and reported by feature controller.
-
#metering ⇒ Google::Apis::GkehubV2::MeteringState
Metering: State for a single membership, analyzed and reported by feature controller.
-
#policycontroller ⇒ Google::Apis::GkehubV2::PolicyControllerState
Policy Controller: State for a single cluster.
-
#rbacrolebindingactuation ⇒ Google::Apis::GkehubV2::RbacRoleBindingActuationState
RBAC RoleBinding Actuation: A membership-specific Feature state for the RBACRoleBindingActuation fleet feature.
-
#servicemesh ⇒ Google::Apis::GkehubV2::ServiceMeshState
Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller.
-
#state ⇒ Google::Apis::GkehubV2::State
High-level state of a MembershipFeature.
-
#workloadidentity ⇒ Google::Apis::GkehubV2::WorkloadIdentityState
WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FeatureState
constructor
A new instance of FeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FeatureState
Returns a new instance of FeatureState.
1611 1612 1613 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appdevexperience ⇒ Google::Apis::GkehubV2::AppDevExperienceState
State for App Dev Exp Feature.
Corresponds to the JSON property appdevexperience
1559 1560 1561 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1559 def appdevexperience @appdevexperience end |
#clusterupgrade ⇒ Google::Apis::GkehubV2::ClusterUpgradeState
Per-membership state for this feature.
Corresponds to the JSON property clusterupgrade
1564 1565 1566 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1564 def clusterupgrade @clusterupgrade end |
#configmanagement ⇒ Google::Apis::GkehubV2::ConfigManagementState
Anthos Config Management: State for a single cluster.
Corresponds to the JSON property configmanagement
1569 1570 1571 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1569 def configmanagement @configmanagement end |
#identityservice ⇒ Google::Apis::GkehubV2::IdentityServiceState
IdentityService: State for a single membership, analyzed and reported by
feature controller.
Corresponds to the JSON property identityservice
1575 1576 1577 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1575 def identityservice @identityservice end |
#metering ⇒ Google::Apis::GkehubV2::MeteringState
Metering: State for a single membership, analyzed and reported by feature
controller.
Corresponds to the JSON property metering
1581 1582 1583 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1581 def metering @metering end |
#policycontroller ⇒ Google::Apis::GkehubV2::PolicyControllerState
Policy Controller: State for a single cluster.
Corresponds to the JSON property policycontroller
1586 1587 1588 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1586 def policycontroller @policycontroller end |
#rbacrolebindingactuation ⇒ Google::Apis::GkehubV2::RbacRoleBindingActuationState
RBAC RoleBinding Actuation: A membership-specific Feature state for the
RBACRoleBindingActuation fleet feature.
Corresponds to the JSON property rbacrolebindingactuation
1592 1593 1594 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1592 def rbacrolebindingactuation @rbacrolebindingactuation end |
#servicemesh ⇒ Google::Apis::GkehubV2::ServiceMeshState
Service Mesh: State for a single Membership, as analyzed by the Service
Mesh Hub Controller.
Corresponds to the JSON property servicemesh
1598 1599 1600 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1598 def servicemesh @servicemesh end |
#state ⇒ Google::Apis::GkehubV2::State
High-level state of a MembershipFeature.
Corresponds to the JSON property state
1603 1604 1605 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1603 def state @state end |
#workloadidentity ⇒ Google::Apis::GkehubV2::WorkloadIdentityState
WorkloadIdentity: The membership-specific state for WorkloadIdentity
feature.
Corresponds to the JSON property workloadidentity
1609 1610 1611 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1609 def workloadidentity @workloadidentity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1616 def update!(**args) @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience) @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade) @configmanagement = args[:configmanagement] if args.key?(:configmanagement) @identityservice = args[:identityservice] if args.key?(:identityservice) @metering = args[:metering] if args.key?(:metering) @policycontroller = args[:policycontroller] if args.key?(:policycontroller) @rbacrolebindingactuation = args[:rbacrolebindingactuation] if args.key?(:rbacrolebindingactuation) @servicemesh = args[:servicemesh] if args.key?(:servicemesh) @state = args[:state] if args.key?(:state) @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity) end |