Class: Google::Apis::GkehubV2::IdentityServiceAzureAdConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Configuration for the AzureAD Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceAzureAdConfig

Returns a new instance of IdentityServiceAzureAdConfig.



1765
1766
1767
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

ID for the registered client application that makes authentication requests to the Azure AD identity provider. Corresponds to the JSON property clientId

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1730

def client_id
  @client_id
end

#client_secretString

Input only. Unencrypted AzureAD client secret will be passed to the GKE Hub CLH. Corresponds to the JSON property clientSecret

Returns:

  • (String)


1736
1737
1738
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1736

def client_secret
  @client_secret
end

#encrypted_client_secretString

Output only. Encrypted AzureAD client secret. Corresponds to the JSON property encryptedClientSecret NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1742
1743
1744
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1742

def encrypted_client_secret
  @encrypted_client_secret
end

#group_formatString

Optional. Format of the AzureAD groups that the client wants for auth. Corresponds to the JSON property groupFormat

Returns:

  • (String)


1747
1748
1749
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1747

def group_format
  @group_format
end

#kubectl_redirect_uriString

The redirect URL that kubectl uses for authorization. Corresponds to the JSON property kubectlRedirectUri

Returns:

  • (String)


1752
1753
1754
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1752

def kubectl_redirect_uri
  @kubectl_redirect_uri
end

#tenantString

Kind of Azure AD account to be authenticated. Supported values are or for accounts belonging to a specific tenant. Corresponds to the JSON property tenant

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1758

def tenant
  @tenant
end

#user_claimString

Optional. Claim in the AzureAD ID Token that holds the user details. Corresponds to the JSON property userClaim

Returns:

  • (String)


1763
1764
1765
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1763

def user_claim
  @user_claim
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1770
1771
1772
1773
1774
1775
1776
1777
1778
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1770

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret)
  @group_format = args[:group_format] if args.key?(:group_format)
  @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri)
  @tenant = args[:tenant] if args.key?(:tenant)
  @user_claim = args[:user_claim] if args.key?(:user_claim)
end