Class: Google::Apis::GkehubV2::IdentityServiceDiagnosticInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Configuration options for the AIS diagnostic interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceDiagnosticInterface

Returns a new instance of IdentityServiceDiagnosticInterface.



1800
1801
1802
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Determines whether to enable the diagnostic interface. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1791
1792
1793
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1791

def enabled
  @enabled
end

#expiration_timeString

Determines the expiration time of the diagnostic interface enablement. When reached, requests to the interface would be automatically rejected. Corresponds to the JSON property expirationTime

Returns:

  • (String)


1798
1799
1800
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1798

def expiration_time
  @expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1805
1806
1807
1808
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1805

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
end