Class: Google::Apis::GkehubV2::IdentityServiceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

IdentityService: State for a single membership, analyzed and reported by feature controller.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceState

Returns a new instance of IdentityServiceState.



2248
2249
2250
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_reasonString

The reason of the failure. Corresponds to the JSON property failureReason

Returns:

  • (String)


2230
2231
2232
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2230

def failure_reason
  @failure_reason
end

#installed_versionString

Installed AIS version. This is the AIS version installed on this member. The values makes sense iff state is OK. Corresponds to the JSON property installedVersion

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2236

def installed_version
  @installed_version
end

#member_configGoogle::Apis::GkehubV2::IdentityServiceSpec

IdentityService: Configuration for a single membership. Corresponds to the JSON property memberConfig



2241
2242
2243
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2241

def member_config
  @member_config
end

#stateString

Deployment state on this member Corresponds to the JSON property state

Returns:

  • (String)


2246
2247
2248
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2246

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2253
2254
2255
2256
2257
2258
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2253

def update!(**args)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @installed_version = args[:installed_version] if args.key?(:installed_version)
  @member_config = args[:member_config] if args.key?(:member_config)
  @state = args[:state] if args.key?(:state)
end