Class: Google::Apis::GkehubV2::PolicyControllerState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Policy Controller: State for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerState

Returns a new instance of PolicyControllerState.



3058
3059
3060
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_statesHash<String,Google::Apis::GkehubV2::PolicyControllerOnClusterState>

Currently these include (also serving as map keys): 1. "admission" 2. "audit"

  1. "mutation" Corresponds to the JSON property componentStates


3045
3046
3047
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3045

def component_states
  @component_states
end

#policy_content_stateGoogle::Apis::GkehubV2::PolicyControllerPolicyContentState

The state of the policy controller policy content Corresponds to the JSON property policyContentState



3050
3051
3052
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3050

def policy_content_state
  @policy_content_state
end

#stateString

The overall Policy Controller lifecycle state observed by the Hub Feature controller. Corresponds to the JSON property state

Returns:

  • (String)


3056
3057
3058
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3056

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3063
3064
3065
3066
3067
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3063

def update!(**args)
  @component_states = args[:component_states] if args.key?(:component_states)
  @policy_content_state = args[:policy_content_state] if args.key?(:policy_content_state)
  @state = args[:state] if args.key?(:state)
end