Class: Google::Apis::GkehubV2::ServiceMeshAnalysisMessageBase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

AnalysisMessageBase describes some common information that is needed for all messages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshAnalysisMessageBase

Returns a new instance of ServiceMeshAnalysisMessageBase.



3269
3270
3271
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentation_urlString

A url pointing to the Service Mesh or Istio documentation for this specific error type. Corresponds to the JSON property documentationUrl

Returns:

  • (String)


3253
3254
3255
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3253

def documentation_url
  @documentation_url
end

#levelString

Represents how severe a message is. Corresponds to the JSON property level

Returns:

  • (String)


3258
3259
3260
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3258

def level
  @level
end

#typeGoogle::Apis::GkehubV2::ServiceMeshType

A unique identifier for the type of message. Display_name is intended to be human-readable, code is intended to be machine readable. There should be a one- to-one mapping between display_name and code. (i.e. do not re-use display_names or codes between message types.) See istio.analysis.v1alpha1. AnalysisMessageBase.Type Corresponds to the JSON property type



3267
3268
3269
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3267

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3274
3275
3276
3277
3278
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3274

def update!(**args)
  @documentation_url = args[:documentation_url] if args.key?(:documentation_url)
  @level = args[:level] if args.key?(:level)
  @type = args[:type] if args.key?(:type)
end