Class: Google::Apis::GkehubV2::ServiceMeshCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::ServiceMeshCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshCondition
constructor
A new instance of ServiceMeshCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshCondition
Returns a new instance of ServiceMeshCondition.
3303 3304 3305 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
3286 3287 3288 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3286 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
3291 3292 3293 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3291 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
3296 3297 3298 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3296 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
3301 3302 3303 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3301 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3308 3309 3310 3311 3312 3313 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3308 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |