Class: Google::Apis::GkehubV2::WorkloadIdentityState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityState

Returns a new instance of WorkloadIdentityState.



3607
3608
3609
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property description

Returns:

  • (String)


3600
3601
3602
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3600

def description
  @description
end

#identity_provider_state_detailsHash<String,Google::Apis::GkehubV2::WorkloadIdentityIdentityProviderStateDetail>

The state of the Identity Providers corresponding to the membership. Corresponds to the JSON property identityProviderStateDetails



3605
3606
3607
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3605

def identity_provider_state_details
  @identity_provider_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3612
3613
3614
3615
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3612

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details)
end