Class: Google::Apis::GkehubV2::ConfigManagementSpec
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::ConfigManagementSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.
Instance Attribute Summary collapse
-
#binauthz ⇒ Google::Apis::GkehubV2::ConfigManagementBinauthzConfig
Configuration for Binauthz.
-
#cluster ⇒ String
Optional.
-
#config_sync ⇒ Google::Apis::GkehubV2::ConfigManagementConfigSync
Configuration for Config Sync Corresponds to the JSON property
configSync. -
#hierarchy_controller ⇒ Google::Apis::GkehubV2::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller.
-
#management ⇒ String
Optional.
-
#policy_controller ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyController
Configuration for Policy Controller Corresponds to the JSON property
policyController. -
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementSpec
constructor
A new instance of ConfigManagementSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementSpec
Returns a new instance of ConfigManagementSpec.
1299 1300 1301 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#binauthz ⇒ Google::Apis::GkehubV2::ConfigManagementBinauthzConfig
Configuration for Binauthz.
Corresponds to the JSON property binauthz
1255 1256 1257 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1255 def binauthz @binauthz end |
#cluster ⇒ String
Optional. User-specified cluster name used by the Config Sync cluster-name-
selector annotation or ClusterSelector object, for applying configs to only a
subset of clusters. Read more about the cluster-name-selector annotation and
ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/
config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this
field if a name different from the cluster's fleet membership name is used by
the Config Sync cluster-name-selector annotation or ClusterSelector.
Corresponds to the JSON property cluster
1266 1267 1268 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1266 def cluster @cluster end |
#config_sync ⇒ Google::Apis::GkehubV2::ConfigManagementConfigSync
Configuration for Config Sync
Corresponds to the JSON property configSync
1271 1272 1273 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1271 def config_sync @config_sync end |
#hierarchy_controller ⇒ Google::Apis::GkehubV2::ConfigManagementHierarchyControllerConfig
Configuration for Hierarchy Controller.
Corresponds to the JSON property hierarchyController
1276 1277 1278 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1276 def hierarchy_controller @hierarchy_controller end |
#management ⇒ String
Optional. Deprecated: In Preview, automatic Feature management is unavailable
from version 1.21.0 onwards, and Config Sync only supports manual upgrades. If
set to manual upgrades, clear this field instead, which is behaviorally
equivalent.
Corresponds to the JSON property management
1284 1285 1286 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1284 def management @management end |
#policy_controller ⇒ Google::Apis::GkehubV2::ConfigManagementPolicyController
Configuration for Policy Controller
Corresponds to the JSON property policyController
1289 1290 1291 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1289 def policy_controller @policy_controller end |
#version ⇒ String
Optional. Version of Config Sync to install. Defaults to the latest supported
Config Sync version if the config_sync field is enabled. See supported
versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get-
support-config-sync#version_support_policy.
Corresponds to the JSON property version
1297 1298 1299 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1297 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1304 1305 1306 1307 1308 1309 1310 1311 1312 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1304 def update!(**args) @binauthz = args[:binauthz] if args.key?(:binauthz) @cluster = args[:cluster] if args.key?(:cluster) @config_sync = args[:config_sync] if args.key?(:config_sync) @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller) @management = args[:management] if args.key?(:management) @policy_controller = args[:policy_controller] if args.key?(:policy_controller) @version = args[:version] if args.key?(:version) end |