Class: Google::Apis::GkehubV2::IdentityServiceLdapConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::IdentityServiceLdapConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Configuration for the LDAP Auth flow.
Instance Attribute Summary collapse
-
#group ⇒ Google::Apis::GkehubV2::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the directory.
-
#server ⇒ Google::Apis::GkehubV2::IdentityServiceServerConfig
Server settings for the external LDAP server.
-
#service_account ⇒ Google::Apis::GkehubV2::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory.
-
#user ⇒ Google::Apis::GkehubV2::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceLdapConfig
constructor
A new instance of IdentityServiceLdapConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceLdapConfig
Returns a new instance of IdentityServiceLdapConfig.
1920 1921 1922 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ Google::Apis::GkehubV2::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the
directory.
Corresponds to the JSON property group
1901 1902 1903 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1901 def group @group end |
#server ⇒ Google::Apis::GkehubV2::IdentityServiceServerConfig
Server settings for the external LDAP server.
Corresponds to the JSON property server
1906 1907 1908 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1906 def server @server end |
#service_account ⇒ Google::Apis::GkehubV2::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform
the LDAP search in the directory. The credentials can be supplied by the
combination of the DN and password or the client certificate.
Corresponds to the JSON property serviceAccount
1913 1914 1915 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1913 def service_account @service_account end |
#user ⇒ Google::Apis::GkehubV2::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Corresponds to the JSON property user
1918 1919 1920 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1918 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1925 1926 1927 1928 1929 1930 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1925 def update!(**args) @group = args[:group] if args.key?(:group) @server = args[:server] if args.key?(:server) @service_account = args[:service_account] if args.key?(:service_account) @user = args[:user] if args.key?(:user) end |