Class: Google::Apis::GkehubV2::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



1918
1919
1920
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV2::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



1899
1900
1901
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1899

def group
  @group
end

#serverGoogle::Apis::GkehubV2::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



1904
1905
1906
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1904

def server
  @server
end

#service_accountGoogle::Apis::GkehubV2::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



1911
1912
1913
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1911

def 
  @service_account
end

#userGoogle::Apis::GkehubV2::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



1916
1917
1918
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1916

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1923
1924
1925
1926
1927
1928
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1923

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end