Class: Google::Apis::GkehubV2::IdentityServiceOidcConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::IdentityServiceOidcConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Configuration for OIDC Auth flow.
Instance Attribute Summary collapse
-
#certificate_authority_data ⇒ String
PEM-encoded CA for OIDC provider.
-
#client_id ⇒ String
ID for OIDC client application.
-
#client_secret ⇒ String
Input only.
-
#deploy_cloud_console_proxy ⇒ Boolean
(also: #deploy_cloud_console_proxy?)
Flag to denote if reverse proxy is used to connect to auth provider.
-
#enable_access_token ⇒ Boolean
(also: #enable_access_token?)
Enable access token.
-
#encrypted_client_secret ⇒ String
Output only.
-
#extra_params ⇒ String
Comma-separated list of key-value pairs.
-
#group_prefix ⇒ String
Prefix to prepend to group name.
-
#groups_claim ⇒ String
Claim in OIDC ID token that holds group information.
-
#issuer_uri ⇒ String
URI for the OIDC provider.
-
#kubectl_redirect_uri ⇒ String
Registered redirect uri to redirect users going through OAuth flow using kubectl plugin.
-
#scopes ⇒ String
Comma-separated list of identifiers.
-
#user_claim ⇒ String
Claim in OIDC ID token that holds username.
-
#user_prefix ⇒ String
Prefix to prepend to user name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceOidcConfig
constructor
A new instance of IdentityServiceOidcConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceOidcConfig
Returns a new instance of IdentityServiceOidcConfig.
2014 2015 2016 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_authority_data ⇒ String
PEM-encoded CA for OIDC provider.
Corresponds to the JSON property certificateAuthorityData
1941 1942 1943 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1941 def @certificate_authority_data end |
#client_id ⇒ String
ID for OIDC client application.
Corresponds to the JSON property clientId
1946 1947 1948 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1946 def client_id @client_id end |
#client_secret ⇒ String
Input only. Unencrypted OIDC client secret will be passed to the GKE Hub CLH.
Corresponds to the JSON property clientSecret
1951 1952 1953 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1951 def client_secret @client_secret end |
#deploy_cloud_console_proxy ⇒ Boolean Also known as: deploy_cloud_console_proxy?
Flag to denote if reverse proxy is used to connect to auth provider. This flag
should be set to true when provider is not reachable by Google Cloud Console.
Corresponds to the JSON property deployCloudConsoleProxy
1957 1958 1959 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1957 def deploy_cloud_console_proxy @deploy_cloud_console_proxy end |
#enable_access_token ⇒ Boolean Also known as: enable_access_token?
Enable access token.
Corresponds to the JSON property enableAccessToken
1963 1964 1965 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1963 def enable_access_token @enable_access_token end |
#encrypted_client_secret ⇒ String
Output only. Encrypted OIDC Client secret
Corresponds to the JSON property encryptedClientSecret
NOTE: Values are automatically base64 encoded/decoded in the client library.
1970 1971 1972 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1970 def encrypted_client_secret @encrypted_client_secret end |
#extra_params ⇒ String
Comma-separated list of key-value pairs.
Corresponds to the JSON property extraParams
1975 1976 1977 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1975 def extra_params @extra_params end |
#group_prefix ⇒ String
Prefix to prepend to group name.
Corresponds to the JSON property groupPrefix
1980 1981 1982 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1980 def group_prefix @group_prefix end |
#groups_claim ⇒ String
Claim in OIDC ID token that holds group information.
Corresponds to the JSON property groupsClaim
1985 1986 1987 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1985 def groups_claim @groups_claim end |
#issuer_uri ⇒ String
URI for the OIDC provider. This should point to the level below .well-known/
openid-configuration.
Corresponds to the JSON property issuerUri
1991 1992 1993 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1991 def issuer_uri @issuer_uri end |
#kubectl_redirect_uri ⇒ String
Registered redirect uri to redirect users going through OAuth flow using
kubectl plugin.
Corresponds to the JSON property kubectlRedirectUri
1997 1998 1999 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 1997 def kubectl_redirect_uri @kubectl_redirect_uri end |
#scopes ⇒ String
Comma-separated list of identifiers.
Corresponds to the JSON property scopes
2002 2003 2004 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2002 def scopes @scopes end |
#user_claim ⇒ String
Claim in OIDC ID token that holds username.
Corresponds to the JSON property userClaim
2007 2008 2009 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2007 def user_claim @user_claim end |
#user_prefix ⇒ String
Prefix to prepend to user name.
Corresponds to the JSON property userPrefix
2012 2013 2014 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2012 def user_prefix @user_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2019 def update!(**args) @certificate_authority_data = args[:certificate_authority_data] if args.key?(:certificate_authority_data) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @deploy_cloud_console_proxy = args[:deploy_cloud_console_proxy] if args.key?(:deploy_cloud_console_proxy) @enable_access_token = args[:enable_access_token] if args.key?(:enable_access_token) @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret) @extra_params = args[:extra_params] if args.key?(:extra_params) @group_prefix = args[:group_prefix] if args.key?(:group_prefix) @groups_claim = args[:groups_claim] if args.key?(:groups_claim) @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri) @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri) @scopes = args[:scopes] if args.key?(:scopes) @user_claim = args[:user_claim] if args.key?(:user_claim) @user_prefix = args[:user_prefix] if args.key?(:user_prefix) end |