Class: Google::Apis::GkehubV2::IdentityServiceServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceServiceAccountConfig

Returns a new instance of IdentityServiceServiceAccountConfig.



2153
2154
2155
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#simple_bind_credentialsGoogle::Apis::GkehubV2::IdentityServiceSimpleBindCredentials

The structure holds the LDAP simple binding credential. Corresponds to the JSON property simpleBindCredentials



2151
2152
2153
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2151

def simple_bind_credentials
  @simple_bind_credentials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2158
2159
2160
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2158

def update!(**args)
  @simple_bind_credentials = args[:simple_bind_credentials] if args.key?(:simple_bind_credentials)
end