Class: Google::Apis::GkehubV2::IdentityServiceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

IdentityService: State for a single membership, analyzed and reported by feature controller.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceState

Returns a new instance of IdentityServiceState.



2246
2247
2248
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_reasonString

The reason of the failure. Corresponds to the JSON property failureReason

Returns:

  • (String)


2228
2229
2230
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2228

def failure_reason
  @failure_reason
end

#installed_versionString

Installed AIS version. This is the AIS version installed on this member. The values makes sense iff state is OK. Corresponds to the JSON property installedVersion

Returns:

  • (String)


2234
2235
2236
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2234

def installed_version
  @installed_version
end

#member_configGoogle::Apis::GkehubV2::IdentityServiceSpec

IdentityService: Configuration for a single membership. Corresponds to the JSON property memberConfig



2239
2240
2241
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2239

def member_config
  @member_config
end

#stateString

Deployment state on this member Corresponds to the JSON property state

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2244

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2251
2252
2253
2254
2255
2256
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2251

def update!(**args)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @installed_version = args[:installed_version] if args.key?(:installed_version)
  @member_config = args[:member_config] if args.key?(:member_config)
  @state = args[:state] if args.key?(:state)
end