Class: Google::Apis::GkehubV2::ListMembershipFeaturesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2::ListMembershipFeaturesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb
Overview
Response message for the GkeHubFeature.ListMembershipFeatures method.
Instance Attribute Summary collapse
-
#membership_features ⇒ Array<Google::Apis::GkehubV2::MembershipFeature>
The list of matching MembershipFeatures.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipFeaturesmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipFeaturesResponse
constructor
A new instance of ListMembershipFeaturesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipFeaturesResponse
Returns a new instance of ListMembershipFeaturesResponse.
2379 2380 2381 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership_features ⇒ Array<Google::Apis::GkehubV2::MembershipFeature>
The list of matching MembershipFeatures.
Corresponds to the JSON property membershipFeatures
2365 2366 2367 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2365 def membership_features @membership_features end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListMembershipFeatures
method. The value of an empty string means that there are no more resources
to return.
Corresponds to the JSON property nextPageToken
2372 2373 2374 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2372 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
2377 2378 2379 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2377 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2384 2385 2386 2387 2388 |
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2384 def update!(**args) @membership_features = args[:membership_features] if args.key?(:membership_features) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |