Class: Google::Apis::GkehubV2::ListMembershipFeaturesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Response message for the GkeHubFeature.ListMembershipFeatures method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipFeaturesResponse

Returns a new instance of ListMembershipFeaturesResponse.



2378
2379
2380
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_featuresArray<Google::Apis::GkehubV2::MembershipFeature>

The list of matching MembershipFeatures. Corresponds to the JSON property membershipFeatures



2364
2365
2366
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2364

def membership_features
  @membership_features
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipFeatures method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2371

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2376
2377
2378
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2376

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2383
2384
2385
2386
2387
# File 'lib/google/apis/gkehub_v2/classes.rb', line 2383

def update!(**args)
  @membership_features = args[:membership_features] if args.key?(:membership_features)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end