Class: Google::Apis::GkehubV2::ServiceMeshSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2/classes.rb,
lib/google/apis/gkehub_v2/representations.rb,
lib/google/apis/gkehub_v2/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshSpec

Returns a new instance of ServiceMeshSpec.



3399
3400
3401
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3380

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


3386
3387
3388
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3386

def control_plane
  @control_plane
end

#default_channelString

Determines which release channel to use for default injection and service mesh APIs. Corresponds to the JSON property defaultChannel

Returns:

  • (String)


3392
3393
3394
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3392

def default_channel
  @default_channel
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3397

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3404
3405
3406
3407
3408
3409
# File 'lib/google/apis/gkehub_v2/classes.rb', line 3404

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @default_channel = args[:default_channel] if args.key?(:default_channel)
  @management = args[:management] if args.key?(:management)
end